import { UnauthorizedComponent } from './unauthorized/unauthorized.component';
import { NgModule } from '@angular/core';
import { RouterModule, Routes } from '@angular/router';
import { HomepageComponent } from './homepage/homepage.component';
import { AuthGuard } from './shared/guards/auth.guard';
import { LoginComponent } from './user-management/login/login.component';
import { WelcomepageComponent } from './welcomepage/welcomepage.component';
import { B2AccessLoginComponent } from './user-management/login/b2access/b2access-login.component';

const appRoutes: Routes = [
  {
    path: 'datasets',
    loadChildren: './datasets/dataset.module#DatasetModule',
    data: {
      // Interpolates values resolved by the router
      breadcrumbs: 'Folder'
    },
    canActivate: [AuthGuard]
  },
  {
    path: 'about',
    loadChildren: './about/about.module#AboutModule',
    data: {
      // Interpolates values resolved by the router
      breadcrumbs: 'About'
    },
    canActivate: [AuthGuard]
  },
  {
    path: 'projects',
    loadChildren: './projects/projects.module#ProjectsModule',
    data: {
      // Interpolates values resolved by the router
      breadcrumbs: 'Projects'
    },
    canActivate: [AuthGuard]
  },
  {
    path: "dmps",
    loadChildren: './dmps/dmps.module#DataManagementPlanModule',
    data: {
      // Interpolates values resolved by the router
      breadcrumbs: 'DMPs'
    },
    canActivate: [AuthGuard]
  },
  {
    path: "dmp-profiles",
    loadChildren: './dmp-profiles/dmp-profile.module#DataManagamentPlanProfileModule',
    data: {
      // Interpolates values resolved by the router
      breadcrumbs: 'DMP Profiles'
    },
    canActivate: [AuthGuard]
  },
  {
    path: 'form',
    loadChildren: './dataset-profile-form/dataset-profile.module#DatasetProfileModule',
    data: {
      // Interpolates values resolved by the router
      breadcrumbs: 'Dataset Profile'
    },
    canActivate: [AuthGuard]
  },
  {
    path: 'home',
    component: HomepageComponent,
    data: {
      // Interpolates values resolved by the router
      breadcrumbs: 'Home'
    },
    canActivate: [AuthGuard]
  },
  {
    path: '',
    redirectTo: '/welcome',
    data: {
      // Interpolates values resolved by the router
      breadcrumbs: 'Home'
    },
    pathMatch: 'full'
  },
  {
    path: "unauthorized",
    loadChildren: './unauthorized/unauthorized.module#UnauthorizedModule',
    data: {
      // Interpolates values resolved by the router
    },
  },
  {
    path: "users",
    loadChildren: './users/users.module#UsersModule'
  },
  {
    path: "datasetsProfiles",
    loadChildren: './datasets-admin-listing/dataset-admin.module#DatasetAdminModule',
    data: {
      // Interpolates values resolved by the router
      breadcrumbs: 'Datasets Profiles'
    },
  },
  {
    path: "welcome",
    component: WelcomepageComponent,
    data: {
      // Interpolates values resolved by the router
      breadcrumbs: 'Home'
    },
  },
  {
    path: "api/oauth/authorized/b2access",
    component: B2AccessLoginComponent,
    data: {
      // Interpolates values resolved by the router
    },
  }
];

@NgModule({
  imports: [
    RouterModule.forRoot(
      appRoutes
      , {
        useHash: false
      }
    )
  ],
  exports: [
    RouterModule
  ]
})
export class AppRoutingModule { }

